@@ -122,7 +122,7 @@ use ffi;
 ///
 /// Use `SQLITE_OK as c_int` to decode return values from mod ffi.
 /// See SqliteResult, SqliteError for typical return code handling.
-#[deriving(Show, PartialEq, Eq, FromPrimitive)]
+#[deriving(Show, PartialEq, Eq, FromPrimitive, Copy)]
 #[allow(non_camel_case_types)]
 #[allow(missing_docs)]
 pub enum SqliteOk {
@@ -730,7 +730,7 @@ mod tests {
             db.prepare("select bogus")
         };
         let err = go().err().unwrap();
-        assert_eq!(err.detail(), Some("no such column: bogus".into_string()))
+        assert_eq!(err.detail(), Some("no such column: bogus".to_string()))
     }
 
     #[test]
